- `PEP 289 – Generator Expressions <https://peps.python.org/pep-0289/>`_
- `Benchmark and discussion during initial implementation <https://github.com/pylint-dev/pylint/pull/3309#discussion_r576683109>`_
